# Forms Reference
## Table of contents


<a href="#user-content-1000">**1000.**</a>
1. <a href="#user-content-physical-exam">Physical Exam</a>
2. <a href="#user-content-patient-history">Patient History</a>
3. <a href="#user-content-other-arv-regimens">Other Arv Regimens</a>
4. <a href="#user-content-glucose-fbgrbg-ogtt">Glucose (Fbg/Rbg, Ogtt)</a>
5. <a href="#user-content-blood-result-insulin">Blood Result: Insulin</a>
6. <a href="#user-content-blood-result-hba1c">Blood Result: Hba1C</a>
7. <a href="#user-content-blood-result-rft">Blood Result: Rft</a>
8. <a href="#user-content-blood-result-lft">Blood Result: Lft</a>
9. <a href="#user-content-blood-result-fbc">Blood Result: Fbc</a>
10. <a href="#user-content-blood-result-lipids">Blood Result: Lipids</a>
11. <a href="#user-content-malaria-test">Malaria Test</a>
12. <a href="#user-content-urine-dipstick-test">Urine Dipstick Test</a>
13. <a href="#user-content-study-medication">Study Medication</a>

<a href="#user-content-1005">**1005.**</a>
1. <a href="#user-content-clinic-follow-up-vitals">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-1">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-1">Study Medication</a>
6. <a href="#user-content-medication-adherence">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey">Sf-12 Health Survey</a>
9. <a href="#user-content-health-economics-m3">Health Economics (M3)</a>

<a href="#user-content-1010">**1010.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-1">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-1">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-2">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-1">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-2">Study Medication</a>
6. <a href="#user-content-medication-adherence-1">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-1">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-1">Sf-12 Health Survey</a>
9. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi">Michigan Neuropathy Screening Instrument (Mnsi)</a>
10. <a href="#user-content-health-economics-m3-1">Health Economics (M3)</a>

<a href="#user-content-1030">**1030.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-2">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-2">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-3">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-2">Glucose (Fbg)</a>
5. <a href="#user-content-blood-result-rft-1">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-1">Blood Result: Lft</a>
7. <a href="#user-content-study-medication-3">Study Medication</a>
8. <a href="#user-content-medication-adherence-2">Medication Adherence</a>
9. <a href="#user-content-euroqol-eq-5d-3l-instrument-2">Euroqol Eq-5D-3L Instrument</a>
10. <a href="#user-content-sf-12-health-survey-2">Sf-12 Health Survey</a>
11. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-1">Michigan Neuropathy Screening Instrument (Mnsi)</a>
12. <a href="#user-content-health-economics-baseline">Health Economics: Baseline</a>

<a href="#user-content-1060">**1060.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-3">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-3">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-4">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-3">Glucose (Fbg)</a>
5. <a href="#user-content-blood-result-rft-2">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-2">Blood Result: Lft</a>
7. <a href="#user-content-blood-result-fbc-1">Blood Result: Fbc</a>
8. <a href="#user-content-study-medication-4">Study Medication</a>
9. <a href="#user-content-medication-adherence-3">Medication Adherence</a>
10. <a href="#user-content-euroqol-eq-5d-3l-instrument-3">Euroqol Eq-5D-3L Instrument</a>
11. <a href="#user-content-sf-12-health-survey-3">Sf-12 Health Survey</a>
12. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-2">Michigan Neuropathy Screening Instrument (Mnsi)</a>
13. <a href="#user-content-health-economics-baseline-1">Health Economics: Baseline</a>

<a href="#user-content-1090">**1090.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-4">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-4">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-5">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-4">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-5">Study Medication</a>
6. <a href="#user-content-medication-adherence-4">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-4">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-4">Sf-12 Health Survey</a>
9. <a href="#user-content-health-economics-baseline-2">Health Economics: Baseline</a>

<a href="#user-content-1120">**1120.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-5">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-5">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-6">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-blood-result-hba1c-1">Blood Result: Hba1C</a>
5. <a href="#user-content-blood-result-rft-3">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-3">Blood Result: Lft</a>
7. <a href="#user-content-blood-result-fbc-2">Blood Result: Fbc</a>
8. <a href="#user-content-blood-result-lipids-1">Blood Result: Lipids</a>
9. <a href="#user-content-study-medication-6">Study Medication</a>
10. <a href="#user-content-medication-adherence-5">Medication Adherence</a>
11. <a href="#user-content-euroqol-eq-5d-3l-instrument-5">Euroqol Eq-5D-3L Instrument</a>
12. <a href="#user-content-sf-12-health-survey-5">Sf-12 Health Survey</a>
13. <a href="#user-content-health-economics-baseline-3">Health Economics: Baseline</a>

<a href="#user-content-1150">**1150.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-6">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-6">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-7">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-5">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-7">Study Medication</a>
6. <a href="#user-content-medication-adherence-6">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-6">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-6">Sf-12 Health Survey</a>
9. <a href="#user-content-health-economics-baseline-4">Health Economics: Baseline</a>

<a href="#user-content-1180">**1180.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-7">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-7">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-8">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-6">Glucose (Fbg)</a>
5. <a href="#user-content-blood-result-fbc-3">Blood Result: Fbc</a>
6. <a href="#user-content-study-medication-8">Study Medication</a>
7. <a href="#user-content-medication-adherence-7">Medication Adherence</a>
8. <a href="#user-content-euroqol-eq-5d-3l-instrument-7">Euroqol Eq-5D-3L Instrument</a>
9. <a href="#user-content-sf-12-health-survey-7">Sf-12 Health Survey</a>
10. <a href="#user-content-health-economics-baseline-5">Health Economics: Baseline</a>

<a href="#user-content-1210">**1210.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-8">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-8">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-9">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-7">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-9">Study Medication</a>
6. <a href="#user-content-medication-adherence-8">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-8">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-8">Sf-12 Health Survey</a>
9. <a href="#user-content-health-economics-baseline-6">Health Economics: Baseline</a>

<a href="#user-content-1240">**1240.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-9">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-9">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-10">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-blood-result-hba1c-2">Blood Result: Hba1C</a>
5. <a href="#user-content-blood-result-rft-4">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-4">Blood Result: Lft</a>
7. <a href="#user-content-blood-result-fbc-4">Blood Result: Fbc</a>
8. <a href="#user-content-blood-result-lipids-2">Blood Result: Lipids</a>
9. <a href="#user-content-study-medication-10">Study Medication</a>
10. <a href="#user-content-medication-adherence-9">Medication Adherence</a>
11. <a href="#user-content-euroqol-eq-5d-3l-instrument-9">Euroqol Eq-5D-3L Instrument</a>
12. <a href="#user-content-sf-12-health-survey-9">Sf-12 Health Survey</a>
13. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-3">Michigan Neuropathy Screening Instrument (Mnsi)</a>
14. <a href="#user-content-health-economics-baseline-7">Health Economics: Baseline</a>

<a href="#user-content-1270">**1270.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-10">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-10">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-11">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-study-medication-11">Study Medication</a>
5. <a href="#user-content-medication-adherence-10">Medication Adherence</a>
6. <a href="#user-content-euroqol-eq-5d-3l-instrument-10">Euroqol Eq-5D-3L Instrument</a>
7. <a href="#user-content-sf-12-health-survey-10">Sf-12 Health Survey</a>
8. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-4">Michigan Neuropathy Screening Instrument (Mnsi)</a>
9. <a href="#user-content-health-economics-baseline-8">Health Economics: Baseline</a>

<a href="#user-content-1300">**1300.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-11">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-11">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-12">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-8">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-12">Study Medication</a>
6. <a href="#user-content-medication-adherence-11">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-11">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-11">Sf-12 Health Survey</a>
9. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-5">Michigan Neuropathy Screening Instrument (Mnsi)</a>
10. <a href="#user-content-health-economics-baseline-9">Health Economics: Baseline</a>

<a href="#user-content-1330">**1330.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-12">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-12">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-13">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-study-medication-13">Study Medication</a>
5. <a href="#user-content-medication-adherence-12">Medication Adherence</a>
6. <a href="#user-content-euroqol-eq-5d-3l-instrument-12">Euroqol Eq-5D-3L Instrument</a>
7. <a href="#user-content-sf-12-health-survey-12">Sf-12 Health Survey</a>
8. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-6">Michigan Neuropathy Screening Instrument (Mnsi)</a>
9. <a href="#user-content-health-economics-baseline-10">Health Economics: Baseline</a>

<a href="#user-content-1360">**1360.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-13">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-13">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-14">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-blood-result-hba1c-3">Blood Result: Hba1C</a>
5. <a href="#user-content-blood-result-rft-5">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-5">Blood Result: Lft</a>
7. <a href="#user-content-blood-result-fbc-5">Blood Result: Fbc</a>
8. <a href="#user-content-blood-result-lipids-3">Blood Result: Lipids</a>
9. <a href="#user-content-study-medication-14">Study Medication</a>
10. <a href="#user-content-medication-adherence-13">Medication Adherence</a>
11. <a href="#user-content-euroqol-eq-5d-3l-instrument-13">Euroqol Eq-5D-3L Instrument</a>
12. <a href="#user-content-sf-12-health-survey-13">Sf-12 Health Survey</a>
13. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-7">Michigan Neuropathy Screening Instrument (Mnsi)</a>
14. <a href="#user-content-health-economics-baseline-11">Health Economics: Baseline</a>

<a href="#user-content-1390">**1390.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-14">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-14">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-15">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-study-medication-15">Study Medication</a>
5. <a href="#user-content-medication-adherence-14">Medication Adherence</a>
6. <a href="#user-content-euroqol-eq-5d-3l-instrument-14">Euroqol Eq-5D-3L Instrument</a>
7. <a href="#user-content-sf-12-health-survey-14">Sf-12 Health Survey</a>
8. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-8">Michigan Neuropathy Screening Instrument (Mnsi)</a>
9. <a href="#user-content-health-economics-baseline-12">Health Economics: Baseline</a>

<a href="#user-content-1420">**1420.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-15">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-15">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-16">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-glucose-fbg-9">Glucose (Fbg)</a>
5. <a href="#user-content-study-medication-16">Study Medication</a>
6. <a href="#user-content-medication-adherence-15">Medication Adherence</a>
7. <a href="#user-content-euroqol-eq-5d-3l-instrument-15">Euroqol Eq-5D-3L Instrument</a>
8. <a href="#user-content-sf-12-health-survey-15">Sf-12 Health Survey</a>
9. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-9">Michigan Neuropathy Screening Instrument (Mnsi)</a>
10. <a href="#user-content-health-economics-baseline-13">Health Economics: Baseline</a>

<a href="#user-content-1450">**1450.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-16">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-16">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-17">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-study-medication-17">Study Medication</a>
5. <a href="#user-content-medication-adherence-16">Medication Adherence</a>
6. <a href="#user-content-euroqol-eq-5d-3l-instrument-16">Euroqol Eq-5D-3L Instrument</a>
7. <a href="#user-content-sf-12-health-survey-16">Sf-12 Health Survey</a>
8. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-10">Michigan Neuropathy Screening Instrument (Mnsi)</a>
9. <a href="#user-content-health-economics-baseline-14">Health Economics: Baseline</a>

<a href="#user-content-1480">**1480.**</a>
1. <a href="#user-content-clinic-follow-up-vitals-17">Clinic Follow Up: Vitals</a>
2. <a href="#user-content-clinic-follow-up-examination-17">Clinic Follow Up: Examination</a>
3. <a href="#user-content-glucose-fbgrbg-ogtt-18">Glucose (Fbg/Rbg, Ogtt)</a>
4. <a href="#user-content-blood-result-hba1c-4">Blood Result: Hba1C</a>
5. <a href="#user-content-blood-result-rft-6">Blood Result: Rft</a>
6. <a href="#user-content-blood-result-lft-6">Blood Result: Lft</a>
7. <a href="#user-content-blood-result-fbc-6">Blood Result: Fbc</a>
8. <a href="#user-content-blood-result-lipids-4">Blood Result: Lipids</a>
9. <a href="#user-content-study-medication-18">Study Medication</a>
10. <a href="#user-content-medication-adherence-17">Medication Adherence</a>
11. <a href="#user-content-euroqol-eq-5d-3l-instrument-17">Euroqol Eq-5D-3L Instrument</a>
12. <a href="#user-content-sf-12-health-survey-17">Sf-12 Health Survey</a>
13. <a href="#user-content-michigan-neuropathy-screening-instrument-mnsi-11">Michigan Neuropathy Screening Instrument (Mnsi)</a>
14. <a href="#user-content-health-economics-baseline-15">Health Economics: Baseline</a>

<a href="#user-content-3000">**3000.**</a>
1. <a href="#user-content-diabetes-endpoint">Diabetes Endpoint</a>

<a href="#user-content-3060">**3060.**</a>
1. <a href="#user-content-diabetes-follow-up-after-referral">Diabetes Follow-Up After Referral</a>

<a href="#user-content-2000">**2000.**</a>
1. <a href="#user-content-delivery">Delivery</a>


### 1000

#### Physical Exam
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_physicalexam
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_physicalexam
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: BP and Heart**

**3.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_physicalexam
- column: sys_blood_pressure_one
- type: IntegerField
---

**4.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_physicalexam
- column: dia_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_physicalexam
- column: sys_blood_pressure_two
- type: IntegerField
---

**6.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_physicalexam
- column: dia_blood_pressure_two
- type: IntegerField
---

**7.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_physicalexam
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_physicalexam
- column: heart_rate
- type: IntegerField
---

**9.0.** Is the heart beat <u>irregular</u>?
- db_table: meta_subject_physicalexam
- column: irregular_heartbeat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If the heartbeat is <u>irregular</u>, please describe
- db_table: meta_subject_physicalexam
- column: irregular_heartbeat_description
- type: TextField
---

**11.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_physicalexam
- column: respiratory_rate
- type: IntegerField
---

**Section: Part 2: Other vitals**

**12.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_physicalexam
- column: temperature
- type: DecimalField
---

**13.0.** Waist circumference

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: meta_subject_physicalexam
- column: waist_circumference
- type: DecimalField
---

**Section: Part 3: Signs**

**14.0.** Jaundice?
- db_table: meta_subject_physicalexam
- column: jaundice
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.0.** Presence of peripheral oedema?
- db_table: meta_subject_physicalexam
- column: peripheral_oedema
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** Abdominal tenderness on palpation?
- db_table: meta_subject_physicalexam
- column: abdominal_tenderness
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** If YES, abdominal tenderness, please describe
- db_table: meta_subject_physicalexam
- column: abdominal_tenderness_description
- type: TextField
---

**18.0.** Enlarged liver on palpation?
- db_table: meta_subject_physicalexam
- column: enlarged_liver
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF Status**

**19.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_physicalexam
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**20.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_physicalexam
- column: crf_status_comments
- type: TextField
---


#### Patient History
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_patienthistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_patienthistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Do you have any of the following symptoms?
- db_table: meta_subject_patienthistory
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** If other, please specify ...
- db_table: meta_subject_patienthistory
- column: other_symptoms
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: HIV, ARVs and other prophylaxis**

**5.0.** When was the diagnosis of HIV made?
- db_table: meta_subject_patienthistory
- column: hiv_diagnosis_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Date of start of antiretroviral therapy (ART)
- db_table: meta_subject_patienthistory
- column: arv_initiation_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Last viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: meta_subject_patienthistory
- column: viral_load
- type: IntegerField
---

**8.0.** Date of last viral load
- db_table: meta_subject_patienthistory
- column: viral_load_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Last CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: meta_subject_patienthistory
- column: cd4
- type: IntegerField
---

**10.0.** Date of last CD4
- db_table: meta_subject_patienthistory
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Which antiretroviral therapy regimen is the patient currently on?
- db_table: meta_subject_patienthistory
- column: current_arv_regimen
- type: ForeignKey
---

**12.0.** If other, please specify ...
- db_table: meta_subject_patienthistory
- column: other_current_arv_regimen
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** When did the patient start this current antiretroviral therapy regimen?
- db_table: meta_subject_patienthistory
- column: current_arv_regimen_start_date
- type: DateField
- format: YYYY-MM-DD
---

**14.0.** Has the patient been on any previous regimen?
- db_table: meta_subject_patienthistory
- column: has_previous_arv_regimen
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.0.** Which antiretroviral therapy regimen was the patient previously on?
- db_table: meta_subject_patienthistory
- column: previous_arv_regimen
- type: ForeignKey
---

**16.0.** If other, please specify ...
- db_table: meta_subject_patienthistory
- column: other_previous_arv_regimen
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** When did the patient start this previous antiretroviral therapy regimen?
- db_table: meta_subject_patienthistory
- column: previous_arv_regimen_start_date
- type: DateField
- format: YYYY-MM-DD
---

**18.0.** Is the patient on any prophylaxis against opportunistic infections?
- db_table: meta_subject_patienthistory
- column: on_oi_prophylaxis
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** If YES, which prophylaxis is the patient on?
- db_table: meta_subject_patienthistory
- column: oi_prophylaxis
- type: ManyToManyField
- responses: *Select all that apply*
  - `tmp_smx`: *TMP/SMX*
  - `fluconazole`: *Fluconazole*
  - `isoniazid`: *Isoniazid*
  - `OTHER`: *Other, specify*
---

**20.0.** If other, please specify ...
- db_table: meta_subject_patienthistory
- column: other_oi_prophylaxis
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 3: Hypertension**

**21.0.** Has the patient been diagnosed with hypertension?
- db_table: meta_subject_patienthistory
- column: htn_diagnosis
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Is the patient on treatment for hypertension?
- db_table: meta_subject_patienthistory
- column: on_htn_treatment
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**23.0.** What medications is the patient currently taking for hypertension?
- db_table: meta_subject_patienthistory
- column: htn_treatment
- type: ManyToManyField
- responses: *Select all that apply*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `captopril`: *Captopril*
  - `diltiazem`: *Diltiazem*
  - `enalapril`: *Enalapril*
  - `eplerenone`: *Eplerenone*
  - `furosemide`: *Furosemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlothiazide`: *Hydrochlothiazide*
  - `indapamide`: *Indapamide*
  - `losartan`: *Losartan*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `perindopril`: *Perindopril*
  - `propanolol`: *Propanolol*
  - `spironolactone`: *Spironolactone*
  - `telmisartan`: *Telmisartan*
  - `torsemide`: *Torsemide*
  - `verapamil`: *Verapamil*
  - `OTHER`: *Other, specify*
---

**24.0.** If other medication(s), please specify ...
- db_table: meta_subject_patienthistory
- column: other_htn_treatment
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**25.0.** Has the patient been diagnosed with dyslipidaemia?
- db_table: meta_subject_patienthistory
- column: dyslipidaemia_diagnosis
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Is the patient on treatment for dyslipidaemia?
- db_table: meta_subject_patienthistory
- column: on_dyslipidaemia_treatment
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**27.0.** What medication is the patient currently taking for dyslipidaemia?
- db_table: meta_subject_patienthistory
- column: dyslipidaemia_rx
- type: CharField
- length: 25
- responses:
  - `atorvastatin`: *Atorvastatin*
  - `rosuvastatin`: *Rosuvastatin*
  - `OTHER`: *Other, specify below ...*
  - `N/A`: *Not applicable*
---

**28.0.** Does the patient have any other conditions not mentioned above?
- db_table: meta_subject_patienthistory
- column: concomitant_conditions
- type: TextField
- length: 250
---

**29.0.** Is the patient taking any concomitant medications?
- db_table: meta_subject_patienthistory
- column: concomitant_medications
- type: TextField
- length: 250
---

**Section: Part 4: Other history**

**30.0.** Is the patient a <u>current</u> smoker?
- db_table: meta_subject_patienthistory
- column: current_smoker
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Is the patient a <u>previous</u> smoker?
- db_table: meta_subject_patienthistory
- column: former_smoker
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**32.0.** In the <u>past year</u>, have you had any of the following symptoms?
- db_table: meta_subject_patienthistory
- column: dm_symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `frequent_urination`: *Wanting to urinate more often than usual*
  - `excessive_thirst`: *Wanting to drink water more than usual*
  - `excessive_eating`: *Wanting to eat food more than usual*
  - `OTHER`: *Other, specify*
  - `none`: *No symptoms to report*
---

**33.0.** If other symptom in the <u>past year</u>, please specify ...
- db_table: meta_subject_patienthistory
- column: other_dm_symptoms
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**34.0.** Has anyone in your immediate family ever been diagnosed with diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Immediate family is parents, siblings, and children*
- db_table: meta_subject_patienthistory
- column: dm_in_family
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF Status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_patienthistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_patienthistory
- column: crf_status_comments
- type: TextField
---


#### Other Arv Regimens
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_otherarvregimens
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_otherarvregimens
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**2.1.** Are there additional ARV regimens to report NOT reported on the Patient History CRF?
- db_table: meta_subject_otherarvregimens
- column: has_other_regimens
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF Status**

**3.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_otherarvregimens
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**4.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_otherarvregimens
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Insulin
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsins
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsins
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsins
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsins
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: INS**

**5.0.** Insulin
- db_table: meta_subject_bloodresultsins
- column: ins_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsins
- column: ins_units
- type: CharField
- length: 15
- responses:
  - `uIU/mL`: *μIU/mL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsins
- column: ins_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsins
- column: ins_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsins
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsins
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultsins
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultsins
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultsins
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultsins
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultsins
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Hba1C
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultshba1c
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultshba1c
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultshba1c
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultshba1c
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HbA1c**

**5.0.** HbA1c value
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_units
- type: CharField
- length: 15
- responses: *free text*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultshba1c
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultshba1c
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultshba1c
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultshba1c
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultshba1c
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultshba1c
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultshba1c
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lipids
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslipids
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslipids
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslipids
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslipids
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: LDL**

**5.0.** LDL
- db_table: meta_subject_bloodresultslipids
- column: ldl_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslipids
- column: ldl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: ldl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: ldl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HDL**

**9.0.** HDL
- db_table: meta_subject_bloodresultslipids
- column: hdl_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslipids
- column: hdl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: hdl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: hdl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: TRIG**

**13.0.** Triglycerides
- db_table: meta_subject_bloodresultslipids
- column: trig_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslipids
- column: trig_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: trig_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: trig_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CHOL**

**17.0.** Total Cholesterol
- db_table: meta_subject_bloodresultslipids
- column: chol_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslipids
- column: chol_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: chol_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: chol_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**21.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslipids
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslipids
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**23.0.** summary
- db_table: meta_subject_bloodresultslipids
- column: summary
- type: TextField
---

**Section: Action**

**24.0.** action identifier
- db_table: meta_subject_bloodresultslipids
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**25.0.** action item
- db_table: meta_subject_bloodresultslipids
- column: action_item
- type: ForeignKey
---

**26.0.** parent action item
- db_table: meta_subject_bloodresultslipids
- column: parent_action_item
- type: ForeignKey
---

**27.0.** related action item
- db_table: meta_subject_bloodresultslipids
- column: related_action_item
- type: ForeignKey
---


#### Malaria Test
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_malariatest
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_malariatest
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Was the malaria test performed?
- db_table: meta_subject_malariatest
- column: performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** Diagnostic test used
- db_table: meta_subject_malariatest
- column: diagnostic_type
- type: CharField
- length: 15
- responses:
  - `rapid_test`: *Rapid test*
  - `microscopy`: *Microscopy*
  - `N/A`: *Not applicable*
---

**5.0.** If NO, provide reason
- db_table: meta_subject_malariatest
- column: not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Result
- db_table: meta_subject_malariatest
- column: result
- type: CharField
- length: 25
- responses:
  - `present`: *Present*
  - `absent`: *Absent*
  - `N/A`: *Not Applicable*
---

**Section: CRF Status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_malariatest
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_malariatest
- column: crf_status_comments
- type: TextField
---


#### Urine Dipstick Test
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_urinedipsticktest
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_urinedipsticktest
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Was the urine dipstick test performed?
- db_table: meta_subject_urinedipsticktest
- column: performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, provide reason
- db_table: meta_subject_urinedipsticktest
- column: not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**5.0.** Ketones?
- db_table: meta_subject_urinedipsticktest
- column: ketones
- type: CharField
- length: 25
- responses:
  - `present`: *Present*
  - `absent`: *Absent*
  - `N/A`: *Not Applicable*
---

**6.0.** Protein?
- db_table: meta_subject_urinedipsticktest
- column: protein
- type: CharField
- length: 25
- responses:
  - `present`: *Present*
  - `absent`: *Absent*
  - `N/A`: *Not Applicable*
---

**7.0.** Glucose?
- db_table: meta_subject_urinedipsticktest
- column: glucose
- type: CharField
- length: 25
- responses:
  - `present`: *Present*
  - `absent`: *Absent*
  - `N/A`: *Not Applicable*
---

**Section: CRF Status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_urinedipsticktest
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_urinedipsticktest
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* fbc

* chemistry_rft

* chemistry_lft

* insulin

### 1005

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics (M3)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicssimple
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicssimple
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Marital status
- db_table: meta_subject_healtheconomicssimple
- column: marital_status
- type: CharField
- length: 25
- responses:
  - `never_married`: *Never married*
  - `married`: *Currently married*
  - `separated`: *Separated*
  - `divorced`: *Divorced*
  - `widowed`: *Widow / Spinster*
---

**4.0.** What is your occupation/profession?
- db_table: meta_subject_healtheconomicssimple
- column: occupation
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Education**

**5.0.** How many years of education did you complete?
- db_table: meta_subject_healtheconomicssimple
- column: education_in_years
- type: IntegerField
---

**6.0.** What is your highest education certificate?
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate
- type: CharField
- length: 50
- responses:
  - `primary`: *Primary Certificate*
  - `secondary`: *Secondary Certificate*
  - `tertiary`: *post-Secondary/Tertiary/College*
  - `OTHER`: *Other, specify ...*
  - `N/A`: *Not applicable, never went to school*
---

**6.1.** If other, please specify ...
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate_other
- type: CharField
- length: 35
- responses: *free text*
---

**7.0.** If your highest education certificate above is `Tertiary`, what type of tertiary certificate?
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate_tertiary
- type: CharField
- length: 50
- responses: *free text*
---

**8.0.** Did you go to primary/elementary school?
- db_table: meta_subject_healtheconomicssimple
- column: primary_school
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: primary_school_in_years
- type: IntegerField
---

**10.0.** Did you go to secondary school?
- db_table: meta_subject_healtheconomicssimple
- column: secondary_school
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: secondary_school_in_years
- type: IntegerField
---

**12.0.** Did you go to higher education?
- db_table: meta_subject_healtheconomicssimple
- column: higher_education
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: higher_education_in_years
- type: IntegerField
---

**Section: CRF Status**

**14.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicssimple
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**15.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicssimple
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1010

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics (M3)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicssimple
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicssimple
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Marital status
- db_table: meta_subject_healtheconomicssimple
- column: marital_status
- type: CharField
- length: 25
- responses:
  - `never_married`: *Never married*
  - `married`: *Currently married*
  - `separated`: *Separated*
  - `divorced`: *Divorced*
  - `widowed`: *Widow / Spinster*
---

**4.0.** What is your occupation/profession?
- db_table: meta_subject_healtheconomicssimple
- column: occupation
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Education**

**5.0.** How many years of education did you complete?
- db_table: meta_subject_healtheconomicssimple
- column: education_in_years
- type: IntegerField
---

**6.0.** What is your highest education certificate?
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate
- type: CharField
- length: 50
- responses:
  - `primary`: *Primary Certificate*
  - `secondary`: *Secondary Certificate*
  - `tertiary`: *post-Secondary/Tertiary/College*
  - `OTHER`: *Other, specify ...*
  - `N/A`: *Not applicable, never went to school*
---

**6.1.** If other, please specify ...
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate_other
- type: CharField
- length: 35
- responses: *free text*
---

**7.0.** If your highest education certificate above is `Tertiary`, what type of tertiary certificate?
- db_table: meta_subject_healtheconomicssimple
- column: education_certificate_tertiary
- type: CharField
- length: 50
- responses: *free text*
---

**8.0.** Did you go to primary/elementary school?
- db_table: meta_subject_healtheconomicssimple
- column: primary_school
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: primary_school_in_years
- type: IntegerField
---

**10.0.** Did you go to secondary school?
- db_table: meta_subject_healtheconomicssimple
- column: secondary_school
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: secondary_school_in_years
- type: IntegerField
---

**12.0.** Did you go to higher education?
- db_table: meta_subject_healtheconomicssimple
- column: higher_education
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** If YES, for how many years
- db_table: meta_subject_healtheconomicssimple
- column: higher_education_in_years
- type: IntegerField
---

**Section: CRF Status**

**14.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicssimple
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**15.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicssimple
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1030

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

### 1060

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

### 1090

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1120

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Hba1C
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultshba1c
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultshba1c
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultshba1c
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultshba1c
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HbA1c**

**5.0.** HbA1c value
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_units
- type: CharField
- length: 15
- responses: *free text*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultshba1c
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultshba1c
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultshba1c
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultshba1c
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultshba1c
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultshba1c
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultshba1c
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lipids
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslipids
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslipids
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslipids
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslipids
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: LDL**

**5.0.** LDL
- db_table: meta_subject_bloodresultslipids
- column: ldl_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslipids
- column: ldl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: ldl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: ldl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HDL**

**9.0.** HDL
- db_table: meta_subject_bloodresultslipids
- column: hdl_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslipids
- column: hdl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: hdl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: hdl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: TRIG**

**13.0.** Triglycerides
- db_table: meta_subject_bloodresultslipids
- column: trig_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslipids
- column: trig_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: trig_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: trig_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CHOL**

**17.0.** Total Cholesterol
- db_table: meta_subject_bloodresultslipids
- column: chol_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslipids
- column: chol_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: chol_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: chol_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**21.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslipids
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslipids
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**23.0.** summary
- db_table: meta_subject_bloodresultslipids
- column: summary
- type: TextField
---

**Section: Action**

**24.0.** action identifier
- db_table: meta_subject_bloodresultslipids
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**25.0.** action item
- db_table: meta_subject_bloodresultslipids
- column: action_item
- type: ForeignKey
---

**26.0.** parent action item
- db_table: meta_subject_bloodresultslipids
- column: parent_action_item
- type: ForeignKey
---

**27.0.** related action item
- db_table: meta_subject_bloodresultslipids
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

* chemistry_lipids

* fbc

### 1150

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1180

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* fbc

### 1210

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1240

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Hba1C
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultshba1c
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultshba1c
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultshba1c
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultshba1c
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HbA1c**

**5.0.** HbA1c value
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_units
- type: CharField
- length: 15
- responses: *free text*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultshba1c
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultshba1c
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultshba1c
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultshba1c
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultshba1c
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultshba1c
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultshba1c
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lipids
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslipids
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslipids
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslipids
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslipids
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: LDL**

**5.0.** LDL
- db_table: meta_subject_bloodresultslipids
- column: ldl_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslipids
- column: ldl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: ldl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: ldl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HDL**

**9.0.** HDL
- db_table: meta_subject_bloodresultslipids
- column: hdl_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslipids
- column: hdl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: hdl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: hdl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: TRIG**

**13.0.** Triglycerides
- db_table: meta_subject_bloodresultslipids
- column: trig_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslipids
- column: trig_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: trig_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: trig_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CHOL**

**17.0.** Total Cholesterol
- db_table: meta_subject_bloodresultslipids
- column: chol_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslipids
- column: chol_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: chol_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: chol_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**21.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslipids
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslipids
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**23.0.** summary
- db_table: meta_subject_bloodresultslipids
- column: summary
- type: TextField
---

**Section: Action**

**24.0.** action identifier
- db_table: meta_subject_bloodresultslipids
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**25.0.** action item
- db_table: meta_subject_bloodresultslipids
- column: action_item
- type: ForeignKey
---

**26.0.** parent action item
- db_table: meta_subject_bloodresultslipids
- column: parent_action_item
- type: ForeignKey
---

**27.0.** related action item
- db_table: meta_subject_bloodresultslipids
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

* chemistry_lipids

* fbc

### 1270

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1300

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

* fbc

### 1330

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1360

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Hba1C
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultshba1c
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultshba1c
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultshba1c
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultshba1c
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HbA1c**

**5.0.** HbA1c value
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_units
- type: CharField
- length: 15
- responses: *free text*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultshba1c
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultshba1c
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultshba1c
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultshba1c
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultshba1c
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultshba1c
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultshba1c
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lipids
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslipids
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslipids
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslipids
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslipids
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: LDL**

**5.0.** LDL
- db_table: meta_subject_bloodresultslipids
- column: ldl_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslipids
- column: ldl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: ldl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: ldl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HDL**

**9.0.** HDL
- db_table: meta_subject_bloodresultslipids
- column: hdl_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslipids
- column: hdl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: hdl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: hdl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: TRIG**

**13.0.** Triglycerides
- db_table: meta_subject_bloodresultslipids
- column: trig_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslipids
- column: trig_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: trig_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: trig_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CHOL**

**17.0.** Total Cholesterol
- db_table: meta_subject_bloodresultslipids
- column: chol_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslipids
- column: chol_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: chol_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: chol_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**21.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslipids
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslipids
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**23.0.** summary
- db_table: meta_subject_bloodresultslipids
- column: summary
- type: TextField
---

**Section: Action**

**24.0.** action identifier
- db_table: meta_subject_bloodresultslipids
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**25.0.** action item
- db_table: meta_subject_bloodresultslipids
- column: action_item
- type: ForeignKey
---

**26.0.** parent action item
- db_table: meta_subject_bloodresultslipids
- column: parent_action_item
- type: ForeignKey
---

**27.0.** related action item
- db_table: meta_subject_bloodresultslipids
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

* chemistry_lipids

* fbc

### 1390

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1420

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Glucose (Fbg)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucosefbg
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucosefbg
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucosefbg
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucosefbg
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucosefbg
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucosefbg
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucosefbg
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucosefbg
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucosefbg
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Confirmation appointment**

**10.0.** repeat fbg date

&nbsp;&nbsp;&nbsp;&nbsp; *Date should be within 1 week of report date*
- db_table: meta_subject_glucosefbg
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucosefbg
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucosefbg
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1450

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1480

#### Clinic Follow Up: Vitals
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupvitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupvitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Vitals**

**3.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: meta_subject_followupvitals
- column: weight
- type: DecimalField
---

**4.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**5.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**6.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: meta_subject_followupvitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**7.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: meta_subject_followupvitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**8.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: meta_subject_followupvitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Heart rate:

&nbsp;&nbsp;&nbsp;&nbsp; *BPM*
- db_table: meta_subject_followupvitals
- column: heart_rate
- type: IntegerField
---

**10.0.** Respiratory rate:

&nbsp;&nbsp;&nbsp;&nbsp; *breaths/min*
- db_table: meta_subject_followupvitals
- column: respiratory_rate
- type: IntegerField
---

**11.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celcius*
- db_table: meta_subject_followupvitals
- column: temperature
- type: DecimalField
---

**Section: CRF Status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupvitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupvitals
- column: crf_status_comments
- type: TextField
---


#### Clinic Follow Up: Examination
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: ['If participant is pregnant, complete the action linked CRF `Pregnancy notification`.']


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_followupexamination
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_followupexamination
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: Symptoms**

**3.0.** Since the participant's last appointment have they experienced any of the following symptoms

&nbsp;&nbsp;&nbsp;&nbsp; *either at this hospital or at a different clinic*
- db_table: meta_subject_followupexamination
- column: symptoms
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**4.0.** Please provide details on any of the symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_detail
- type: TextField
---

**5.0.** For these symptoms, were any grade 3 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g3
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**6.0.** Please provide details on any of the Grade 3 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g3_detail
- type: TextField
---

**7.0.** For these symptoms, were any grade 4 events

&nbsp;&nbsp;&nbsp;&nbsp; *Refer to DAIDS toxicity table. Please complete Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: symptoms_g4
- type: ManyToManyField
- responses: *Select all that apply*
  - `none`: *--No symptoms to report*
  - `abdominal_pain_general`: *Abdominal pain (General)*
  - `abdominal_pain_right_upper_quad`: *Abdominal pain (Right upper quadrant)*
  - `blurred_vision`: *Blurred vision*
  - `diarrhoea`: *Diarrhoea*
  - `dizziness`: *Dizziness*
  - `fatigue`: *Fatigue*
  - `flatulence`: *Flatulence (gas)*
  - `headaches`: *Headaches*
  - `increased_appetite`: *Increased appetite*
  - `joint_pain`: *Joint pain*
  - `loss_of_appetite`: *Loss of appetite*
  - `muscle_cramping`: *Muscle cramping*
  - `muscle_pain`: *Muscle pain*
  - `nausea`: *Nausea*
  - `pain_feet_or_lower_limbs`: *Pain in feet/lower limbs*
  - `pounding_heartbeat`: *Fast or pounding heartbeat*
  - `rash`: *Rash*
  - `shakiness`: *Shakiness*
  - `shallow_breathing`: *Fast or shallow breathing*
  - `skin_itching`: *Skin itching*
  - `sweating`: *Sweating*
  - `swelling_feet_or_lower_limbs`: *Swelling of feet/lower limbs*
  - `unusual_sleepiness`: *Unusual sleepiness*
  - `vomiting`: *Vomiting*
  - `weakness`: *Weakness*
  - `OTHER`: *Other, specify*
---

**8.0.** Please provide details on any of the Grade 4 symptoms above.
- db_table: meta_subject_followupexamination
- column: symptoms_g4_detail
- type: TextField
---

**Section: Part 2: Other Medical or Health problems**

**8.1.** Since your last visit has the participant experienced any other medical or health problems NOT listed above
- db_table: meta_subject_followupexamination
- column: any_other_problems
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.2.** If YES, please provide details of the event
- db_table: meta_subject_followupexamination
- column: any_other_problems_detail
- type: TextField
---

**8.3.** Does this event constitute an Adverse Event?
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.4.** If YES, what grade?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, grade 3 or 4, submit Serious Adverse Event form*
- db_table: meta_subject_followupexamination
- column: any_other_problems_sae_grade
- type: CharField
- length: 25
- responses:
  - `3`: *Grade 3*
  - `4`: *Grade 4*
  - `N/A`: *Not applicable*
---

**Section: Part 3: Hospitalizations or other external access to care**

**9.0.** Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason

&nbsp;&nbsp;&nbsp;&nbsp; *Includes other routine appointments, e.g. BP check or family planning*
- db_table: meta_subject_followupexamination
- column: attended_clinic
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If YES, attend clinic or hospital, please provide details of this event

&nbsp;&nbsp;&nbsp;&nbsp; *If the participant was given a referral letter or discharge summary record details here*
- db_table: meta_subject_followupexamination
- column: attended_clinic_detail
- type: TextField
---

**11.0.** If YES, were they admitted to hospital?
- db_table: meta_subject_followupexamination
- column: admitted_hospital
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Does the event constitute a <u>Serious Adverse Event</u>

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, submit a <u>Serious Adverse Event</u> Form*
- db_table: meta_subject_followupexamination
- column: attended_clinic_sae
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Was the participant prescribed any other medication at this clinic or hospital visit?
- db_table: meta_subject_followupexamination
- column: prescribed_medication
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** If YES, prescribed any other medication, please provide details of this visit
- db_table: meta_subject_followupexamination
- column: prescribed_medication_detail
- type: TextField
---

**Section: Part 4: HIV Medications**

**15.0.** Since the participant's last visit has there been any change in their HIV medication?
- db_table: meta_subject_followupexamination
- column: art_change
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** If YES, please provide reason for change
- db_table: meta_subject_followupexamination
- column: art_change_reason
- type: TextField
---

**17.0.** Please indicate new regimen
- db_table: meta_subject_followupexamination
- column: art_new_regimen
- type: ForeignKey
---

**17.1.** If other, please specify ...
- db_table: meta_subject_followupexamination
- column: art_new_regimen_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Part 2: Examination**

**18.0.** Abdominal tenderness
- db_table: meta_subject_followupexamination
- column: abdominal_tenderness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**19.0.** Enlarged liver
- db_table: meta_subject_followupexamination
- column: enlarged_liver
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**20.0.** Jaundice
- db_table: meta_subject_followupexamination
- column: jaundice
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_evaluated`: *Not evaluated*
---

**Section: Part 3: Summary**

**21.0.** Comment on the clinical course, any other symptoms present, assessment and management plan
- db_table: meta_subject_followupexamination
- column: comment
- type: TextField
---

**22.0.** Do you think the participant has lactic acidosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.*
- db_table: meta_subject_followupexamination
- column: lactic_acidosis
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Do you think the participant has hepatomegaly with steatosis?

&nbsp;&nbsp;&nbsp;&nbsp; *Submit SAE form. This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome*
- db_table: meta_subject_followupexamination
- column: hepatomegaly
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Is the participant being referred
- db_table: meta_subject_followupexamination
- column: referral
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** If YES, where are they being referred to

&nbsp;&nbsp;&nbsp;&nbsp; *Note: remind participant that admission or discharge information will be needed at the next follow up visit.*
- db_table: meta_subject_followupexamination
- column: referral_reason
- type: TextField
---

**Section: CRF Status**

**26.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_followupexamination
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**27.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_followupexamination
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**28.0.** action identifier
- db_table: meta_subject_followupexamination
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** action item
- db_table: meta_subject_followupexamination
- column: action_item
- type: ForeignKey
---

**30.0.** parent action item
- db_table: meta_subject_followupexamination
- column: parent_action_item
- type: ForeignKey
---

**31.0.** related action item
- db_table: meta_subject_followupexamination
- column: related_action_item
- type: ForeignKey
---


#### Glucose (Fbg/Rbg, Ogtt)
A user model to capture both FBG/RBG and OGTT

    See also GlucoseFbg.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_glucose
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_glucose
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Fasting**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: meta_subject_glucose
- column: fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: meta_subject_glucose
- column: fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose**

**5.0.** Was the FBG test performed?
- db_table: meta_subject_glucose
- column: fbg_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: fbg_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** FBG date/time measured
- db_table: meta_subject_glucose
- column: fbg_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** FBG level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: fbg_value
- type: DecimalField
---

**9.0.** FBG units
- db_table: meta_subject_glucose
- column: fbg_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: OGTT**

**10.0.** Was the OGTT test performed?
- db_table: meta_subject_glucose
- column: ogtt_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**11.0.** If NO, provide reason
- db_table: meta_subject_glucose
- column: ogtt_not_performed_reason
- type: CharField
- length: 150
- responses: *free text*
---

**12.0.** Date/time oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_base_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**13.0.** Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *(2 hours after glucose solution given)*
- db_table: meta_subject_glucose
- column: ogtt_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**14.0.** Blood glucose measure 2hrs <u>after</u> oral glucose solution given

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: meta_subject_glucose
- column: ogtt_value
- type: DecimalField
---

**15.0.** Units (Blood glucose 2hrs after...)
- db_table: meta_subject_glucose
- column: ogtt_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: Endpoint review**

**16.0.** Has the participant reached a study endpoint today?

&nbsp;&nbsp;&nbsp;&nbsp; *Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed*
- db_table: meta_subject_glucose
- column: endpoint_today
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `PENDING`: *No. A repeat FBG will be scheduled*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** If required, date particpant to repeat FBG
- db_table: meta_subject_glucose
- column: repeat_fbg_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF Status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_glucose
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_glucose
- column: crf_status_comments
- type: TextField
---


#### Blood Result: Hba1C
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultshba1c
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultshba1c
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultshba1c
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultshba1c
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HbA1c**

**5.0.** HbA1c value
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_units
- type: CharField
- length: 15
- responses: *free text*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultshba1c
- column: hba1c_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**9.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultshba1c
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultshba1c
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**11.0.** summary
- db_table: meta_subject_bloodresultshba1c
- column: summary
- type: TextField
---

**Section: Action**

**12.0.** action identifier
- db_table: meta_subject_bloodresultshba1c
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** action item
- db_table: meta_subject_bloodresultshba1c
- column: action_item
- type: ForeignKey
---

**14.0.** parent action item
- db_table: meta_subject_bloodresultshba1c
- column: parent_action_item
- type: ForeignKey
---

**15.0.** related action item
- db_table: meta_subject_bloodresultshba1c
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Rft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsrft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsrft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsrft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsrft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: UREA**

**5.0.** Urea (BUN)
- db_table: meta_subject_bloodresultsrft
- column: urea_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsrft
- column: urea_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: urea_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: urea_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CREATININE**

**9.0.** Creatinine
- db_table: meta_subject_bloodresultsrft
- column: creatinine_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsrft
- column: creatinine_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `umol/L`: *μmol/L (micromoles/L)*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: creatinine_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: creatinine_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: URIC_ACID**

**13.0.** Uric Acid
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `mg/dL`: *mg/dL*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsrft
- column: uric_acid_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Calculated eGFR**

**17.0.** eGFR
- db_table: meta_subject_bloodresultsrft
- column: egfr_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_units
- type: CharField
- length: 15
- responses:
  - `mL/min/1.73m2`: *mL/min/1.73m2*
---

**19.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_grade
- type: IntegerField
---

**Section: Calculated eGFR Drop**

**20.0.** eGFR Drop
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_value
- type: DecimalField
---

**21.0.** units
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**22.0.** Grade
- db_table: meta_subject_bloodresultsrft
- column: egfr_drop_grade
- type: IntegerField
---

**Section: Conclusion**

**23.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsrft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsrft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**25.0.** summary
- db_table: meta_subject_bloodresultsrft
- column: summary
- type: TextField
---

**Section: Action**

**26.0.** action identifier
- db_table: meta_subject_bloodresultsrft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**27.0.** action item
- db_table: meta_subject_bloodresultsrft
- column: action_item
- type: ForeignKey
---

**28.0.** parent action item
- db_table: meta_subject_bloodresultsrft
- column: parent_action_item
- type: ForeignKey
---

**29.0.** related action item
- db_table: meta_subject_bloodresultsrft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lft
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslft
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslft
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslft
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslft
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: AST**

**5.0.** AST
- db_table: meta_subject_bloodresultslft
- column: ast_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslft
- column: ast_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ast_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ast_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALT**

**9.0.** ALT
- db_table: meta_subject_bloodresultslft
- column: alt_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslft
- column: alt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALP**

**13.0.** ALP
- db_table: meta_subject_bloodresultslft
- column: alp_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslft
- column: alp_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: alp_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: alp_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: AMYLASE**

**17.0.** Serum Amylase
- db_table: meta_subject_bloodresultslft
- column: amylase_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslft
- column: amylase_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: amylase_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: amylase_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: GGT**

**21.0.** GGT
- db_table: meta_subject_bloodresultslft
- column: ggt_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultslft
- column: ggt_units
- type: CharField
- length: 15
- responses:
  - `IU/L`: *IU/L*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: ggt_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: ggt_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: ALBUMIN**

**25.0.** Serum albumin
- db_table: meta_subject_bloodresultslft
- column: albumin_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultslft
- column: albumin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
  - `g/L`: *g/L*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultslft
- column: albumin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultslft
- column: albumin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**29.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslft
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslft
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**31.0.** summary
- db_table: meta_subject_bloodresultslft
- column: summary
- type: TextField
---

**Section: Action**

**32.0.** action identifier
- db_table: meta_subject_bloodresultslft
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**33.0.** action item
- db_table: meta_subject_bloodresultslft
- column: action_item
- type: ForeignKey
---

**34.0.** parent action item
- db_table: meta_subject_bloodresultslft
- column: parent_action_item
- type: ForeignKey
---

**35.0.** related action item
- db_table: meta_subject_bloodresultslft
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Fbc
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultsfbc
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultsfbc
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultsfbc
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultsfbc
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Haemoglobin**

**5.0.** Haemoglobin
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: haemoglobin_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HCT**

**9.0.** Hematocrit
- db_table: meta_subject_bloodresultsfbc
- column: hct_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: hct_units
- type: CharField
- length: 15
- responses:
  - `%`: *%*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: hct_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: hct_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: RBC**

**13.0.** Red blood cell count
- db_table: meta_subject_bloodresultsfbc
- column: rbc_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: rbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm^3*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: rbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: rbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: WBC**

**17.0.** WBC
- db_table: meta_subject_bloodresultsfbc
- column: wbc_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: wbc_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: wbc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: wbc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: PLATELETS**

**21.0.** Platelets
- db_table: meta_subject_bloodresultsfbc
- column: platelets_value
- type: DecimalField
---

**22.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: platelets_units
- type: CharField
- length: 15
- responses:
  - `10^9/L`: *10^9/L*
  - `cells/mm^3`: *cells/mm<sup>3</sup>*
---

**23.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: platelets_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: platelets_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCV**

**25.0.** MCV
- db_table: meta_subject_bloodresultsfbc
- column: mcv_value
- type: DecimalField
---

**26.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mcv_units
- type: CharField
- length: 15
- responses:
  - `fL/cell`: *fL/cell*
---

**27.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mcv_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mcv_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCH**

**29.0.** MCH
- db_table: meta_subject_bloodresultsfbc
- column: mch_value
- type: DecimalField
---

**30.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mch_units
- type: CharField
- length: 15
- responses:
  - `pg/cell`: *pg/cell*
---

**31.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mch_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mch_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: MCHC**

**33.0.** MCHC
- db_table: meta_subject_bloodresultsfbc
- column: mchc_value
- type: DecimalField
---

**34.0.** units
- db_table: meta_subject_bloodresultsfbc
- column: mchc_units
- type: CharField
- length: 15
- responses:
  - `g/dL`: *g/dL*
---

**35.0.** abnormal
- db_table: meta_subject_bloodresultsfbc
- column: mchc_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**36.0.** reportable
- db_table: meta_subject_bloodresultsfbc
- column: mchc_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**37.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultsfbc
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**38.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultsfbc
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**39.0.** summary
- db_table: meta_subject_bloodresultsfbc
- column: summary
- type: TextField
---

**Section: Action**

**40.0.** action identifier
- db_table: meta_subject_bloodresultsfbc
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**41.0.** action item
- db_table: meta_subject_bloodresultsfbc
- column: action_item
- type: ForeignKey
---

**42.0.** parent action item
- db_table: meta_subject_bloodresultsfbc
- column: parent_action_item
- type: ForeignKey
---

**43.0.** related action item
- db_table: meta_subject_bloodresultsfbc
- column: related_action_item
- type: ForeignKey
---


#### Blood Result: Lipids
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_bloodresultslipids
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_bloodresultslipids
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: meta_subject_bloodresultslipids
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: meta_subject_bloodresultslipids
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: LDL**

**5.0.** LDL
- db_table: meta_subject_bloodresultslipids
- column: ldl_value
- type: DecimalField
---

**6.0.** units
- db_table: meta_subject_bloodresultslipids
- column: ldl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**7.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: ldl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: ldl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: HDL**

**9.0.** HDL
- db_table: meta_subject_bloodresultslipids
- column: hdl_value
- type: DecimalField
---

**10.0.** units
- db_table: meta_subject_bloodresultslipids
- column: hdl_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**11.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: hdl_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: hdl_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: TRIG**

**13.0.** Triglycerides
- db_table: meta_subject_bloodresultslipids
- column: trig_value
- type: DecimalField
---

**14.0.** units
- db_table: meta_subject_bloodresultslipids
- column: trig_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**15.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: trig_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**16.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: trig_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: CHOL**

**17.0.** Total Cholesterol
- db_table: meta_subject_bloodresultslipids
- column: chol_value
- type: DecimalField
---

**18.0.** units
- db_table: meta_subject_bloodresultslipids
- column: chol_units
- type: CharField
- length: 15
- responses:
  - `mmol/L`: *mmol/L*
---

**19.0.** abnormal
- db_table: meta_subject_bloodresultslipids
- column: chol_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** reportable
- db_table: meta_subject_bloodresultslipids
- column: chol_reportable
- type: CharField
- length: 25
- responses:
  - `N/A`: *Not applicable*
  - `3`: *Yes, grade 3*
  - `4`: *Yes, grade 4*
  - `No`: *Not reportable*
  - `Already reported`: *Already reported*
  - `present_at_baseline`: *Present at baseline*
---

**Section: Conclusion**

**21.0.** Are any of the above results abnormal?

&nbsp;&nbsp;&nbsp;&nbsp; *Abnormal results present at baseline or continuing from baseline not included.*
- db_table: meta_subject_bloodresultslipids
- column: results_abnormal
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** If any results are abnormal, are results within grade 3 or above?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included*
- db_table: meta_subject_bloodresultslipids
- column: results_reportable
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Summary**

**23.0.** summary
- db_table: meta_subject_bloodresultslipids
- column: summary
- type: TextField
---

**Section: Action**

**24.0.** action identifier
- db_table: meta_subject_bloodresultslipids
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**25.0.** action item
- db_table: meta_subject_bloodresultslipids
- column: action_item
- type: ForeignKey
---

**26.0.** parent action item
- db_table: meta_subject_bloodresultslipids
- column: parent_action_item
- type: ForeignKey
---

**27.0.** related action item
- db_table: meta_subject_bloodresultslipids
- column: related_action_item
- type: ForeignKey
---


#### Study Medication
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_studymedication
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_studymedication
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Will the subject receive study medication for this visit

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, set refill_start_datetime equal to the refill_end_datetime*
- db_table: meta_subject_studymedication
- column: refill
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Details**

**4.0.** refill start datetime
- db_table: meta_subject_studymedication
- column: refill_start_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**5.0.** dosage guideline
- db_table: meta_subject_studymedication
- column: dosage_guideline
- type: ForeignKey
---

**6.0.** formulation
- db_table: meta_subject_studymedication
- column: formulation
- type: ForeignKey
---

**7.0.** Refill to the next scheduled visit

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, leave refill end date blank to auto-calculate*
- db_table: meta_subject_studymedication
- column: refill_to_next_visit
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** refill end datetime

&nbsp;&nbsp;&nbsp;&nbsp; *Leave blank to auto-calculate if refilling to the next scheduled visit*
- db_table: meta_subject_studymedication
- column: refill_end_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**9.0.** special instructions
- db_table: meta_subject_studymedication
- column: special_instructions
- type: TextField
---

**Section: Dispensed medication**

**10.0.** stock codes

&nbsp;&nbsp;&nbsp;&nbsp; *Enter the medication bottle barcode or barcodes seperated by comma, no spaces*
- db_table: meta_subject_studymedication
- column: stock_codes
- type: CharField
- length: 30
- responses: *free text*
---

**Section: CRF Status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_studymedication
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_studymedication
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_medicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_medicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_medicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Pill Count**

**5.0.** Was a pill count performed
- db_table: meta_subject_medicationadherence
- column: pill_count_performed
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Number of pills left in the bottle
- db_table: meta_subject_medicationadherence
- column: pill_count
- type: IntegerField
---

**7.0.** If not performed, please explain ...
- db_table: meta_subject_medicationadherence
- column: pill_count_not_performed_reason
- type: TextField
---

**Section: Missed Medications**

**8.0.** When was the last time you missed your study pill?
- db_table: meta_subject_medicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**9.0.** Reasons for missing study pills
- db_table: meta_subject_medicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forget_to_take`: *I sometimes forget to take my pills*
  - `dont_like_taking`: *I don't like taking my pills*
  - `make_me_ill`: *My pills sometimes make me feel sick*
  - `misplaced_pills`: *I sometimes misplace my pills*
  - `dont_believe_pills_help`: *I don't believe my pills are helping me*
  - `dont_believe_pills_needed`: *I don't believe I need to take my pills*
  - `not_feeling_well`: *I have not been feeling well*
  - `OTHER`: *Other, please specify ...*
---

**10.0.** If other, please specify ...
- db_table: meta_subject_medicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: meta_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: meta_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: meta_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: meta_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: meta_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: meta_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: meta_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_eq5d3l
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_eq5d3l
- column: crf_status_comments
- type: TextField
---


#### Sf-12 Health Survey
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_sf12
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_sf12
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1: General health**

**3.0.** In general, would you say your health is:
- db_table: meta_subject_sf12
- column: general_health
- type: CharField
- length: 15
- responses:
  - `excellent`: *Excellent*
  - `very_good`: *Very good*
  - `good`: *Good*
  - `fair`: *Fair*
  - `poor`: *Poor*
---

**Section: Part 2: Activities limited by health**

**4.0.** <u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:
- db_table: meta_subject_sf12
- column: moderate_activities_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**5.0.** Climbing <u>several</u> flights of stairs:
- db_table: meta_subject_sf12
- column: climbing_stairs_now_limited
- type: CharField
- length: 20
- responses:
  - `limited_a_lot`: *YES, limited a lot*
  - `limited_a_little`: *YES, limited a little*
  - `not_limited_at_all`: *NO, not at all limited*
---

**Section: Part 3: Physical health problems (last 4 weeks)**

**6.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** Were limited in the <u>kind</u> of work or other activities:
- db_table: meta_subject_sf12
- column: work_limited_physical_health
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 4: Emotional problems (last 4 weeks)**

**8.0.** <u>Accomplished less</u> than you would like:
- db_table: meta_subject_sf12
- column: accomplished_less_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Did work or activities <u>less carefully than usual</u>:
- db_table: meta_subject_sf12
- column: work_less_carefully_emotional
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Part 5: Pain (last 4 weeks)**

**10.0.** During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?
- db_table: meta_subject_sf12
- column: pain_interfere_work
- type: CharField
- length: 15
- responses:
  - `not_at_all`: *Not at all*
  - `a_little_bit`: *A little bit*
  - `moderately`: *Moderately*
  - `quite_a-bit`: *Quite a bit*
  - `extremely`: *Extremely*
---

**Section: Part 6: Feeling (last 4 weeks)**

**11.0.** Have you felt calm & peaceful?
- db_table: meta_subject_sf12
- column: felt_calm_peaceful
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**12.0.** Did you have a lot of energy?
- db_table: meta_subject_sf12
- column: felt_lot_energy
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**13.0.** Have you felt down-hearted and blue?
- db_table: meta_subject_sf12
- column: felt_down
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `good_bit_of_the_time`: *A good bit of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: Part 7: Social activities (last 4 weeks)**

**14.0.** During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?
- db_table: meta_subject_sf12
- column: social_activities_interfered
- type: CharField
- length: 25
- responses:
  - `all_of_the_time`: *All of the time*
  - `most_of_the_time`: *Most of the time*
  - `some_of_the_time`: *Some of the time*
  - `little_of_the_time`: *A little of the time*
  - `none_of_the_time`: *None of the time*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_sf12
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_sf12
- column: crf_status_comments
- type: TextField
---


#### Michigan Neuropathy Screening Instrument (Mnsi)
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_mnsi
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_mnsi
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**3.0.** Is the MNSI assessment being performed?

&nbsp;&nbsp;&nbsp;&nbsp; *If completion of patient history or physical assessment not possible, respond with `no` and provide reason below.*
- db_table: meta_subject_mnsi
- column: mnsi_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If NO, please provide a reason
- db_table: meta_subject_mnsi
- column: mnsi_not_performed_reason
- type: TextField
- length: 200
---

**Section: Part 1: Patient History**

**5.0.** Are your legs and/or feet numb?
- db_table: meta_subject_mnsi
- column: numb_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**6.0.** Do you ever have any burning pain in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: burning_pain_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**7.0.** Are your feet too sensitive to touch?
- db_table: meta_subject_mnsi
- column: feet_sensitive_touch
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Do you get muscle cramps in your legs and/or feet?
- db_table: meta_subject_mnsi
- column: muscle_cramps_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Do you ever have any prickling feelings in your legs or feet?
- db_table: meta_subject_mnsi
- column: prickling_feelings_legs_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** Does it hurt when the bed covers touch your skin?
- db_table: meta_subject_mnsi
- column: covers_touch_skin_painful
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**11.0.** When you get into the tub or shower, are you able to tell the hot water from the cold water?
- db_table: meta_subject_mnsi
- column: differentiate_hot_cold_water
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Have you ever had an open sore on your foot?
- db_table: meta_subject_mnsi
- column: open_sore_foot_history
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** Has your doctor ever told you that you have diabetic neuropathy?
- db_table: meta_subject_mnsi
- column: diabetic_neuropathy
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**14.0.** Do you feel weak all over most of the time?
- db_table: meta_subject_mnsi
- column: feel_weak
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Are your symptoms worse at night?
- db_table: meta_subject_mnsi
- column: symptoms_worse_night
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** Do your legs hurt when you walk?
- db_table: meta_subject_mnsi
- column: legs_hurt_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**17.0.** Are you able to sense your feet when you walk?
- db_table: meta_subject_mnsi
- column: sense_feet_when_walk
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** Is the skin on your feet so dry that it cracks open?
- db_table: meta_subject_mnsi
- column: skin_cracks_open_feet
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**19.0.** Have you ever had an amputation?
- db_table: meta_subject_mnsi
- column: amputation
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Part 2a: Physical Assessment - Right Foot**

**20.0.** Does RIGHT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_right_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**21.0.** If NO, check all that apply to RIGHT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**21.1.** If other abnormality observed on RIGHT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_right_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**22.0.** Ulceration, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_right_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**23.0.** Ankle reflexes, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_right_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**24.0.** Vibration perception at great toe, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_right_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**25.0.** Monofilament, RIGHT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_right_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: Part 2b: Physical Assessment - Left Foot**

**26.0.** Does LEFT foot appear normal?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: normal_appearance_left_foot
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `not_examined`: *Not examined*
---

**27.0.** If NO, check all that apply to LEFT foot?
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot
- type: ManyToManyField
- responses: *Select all that apply*
  - `deformities`: *Deformities*
  - `callous_formation`: *Callous formation*
  - `dry_skin_callus`: *Dry skin, callus*
  - `deformity_amputation`: *Deformity – amputation*
  - `deformity_flat_feet`: *Deformity – flat feet*
  - `deformity_halux_valgus`: *Deformity – halux valgus*
  - `deformity_hammer_toes`: *Deformity – hammer toes*
  - `deformity_joint_subluxation`: *Deformity – joint subluxation*
  - `deformity_medial_convexity`: *Deformity – medial convexity (Charcot foot)*
  - `deformity_overlapping_toes`: *Deformity – overlapping toes*
  - `deformity_prominent_metatarsal_heads`: *Deformity – prominent metatarsal heads*
  - `dry_skin`: *Dry skin*
  - `infection`: *Infection*
  - `fissure`: *Fissure*
  - `OTHER`: *Other abnormality, please specify*
---

**27.1.** If other abnormality observed on LEFT foot, please specify ...
- db_table: meta_subject_mnsi
- column: abnormal_obs_left_foot_other
- type: CharField
- length: 35
- responses: *free text*
---

**28.0.** Ulceration, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ulceration_left_foot
- type: CharField
- length: 35
- responses:
  - `absent`: *Absent*
  - `present`: *Present*
  - `not_examined`: *Not examined*
---

**29.0.** Ankle reflexes, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: ankle_reflexes_left_foot
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `present_with_reinforcement`: *Present/Reinforcement*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**30.0.** Vibration perception at great toe, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: vibration_perception_left_toe
- type: CharField
- length: 35
- responses:
  - `present`: *Present*
  - `decreased`: *Decreased*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**31.0.** Monofilament, LEFT foot?

&nbsp;&nbsp;&nbsp;&nbsp; *If the MNSI assessment was not performed, or amputation prevents examination, respond with `not examined`.*
- db_table: meta_subject_mnsi
- column: monofilament_left_foot
- type: CharField
- length: 35
- responses:
  - `NORMAL`: *Normal*
  - `reduced`: *Reduced*
  - `absent`: *Absent*
  - `not_examined`: *Not examined*
---

**Section: CRF status**

**32.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_mnsi
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**33.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_mnsi
- column: crf_status_comments
- type: TextField
---

**Section: Calculated values**

**34.0.** calculated patient history score
- db_table: meta_subject_mnsi
- column: calculated_patient_history_score
- type: IntegerField
---

**35.0.** calculated physical assessment score
- db_table: meta_subject_mnsi
- column: calculated_physical_assessment_score
- type: DecimalField
---


#### Health Economics: Baseline
A user model to learn about the household, wealth and
    opportunities in the community

    Introduced 22 FEB 2024

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these
        questions to get an understanding of wealth and opportunities
        in the community. A person or persons (people/ members) who share
        the same kitchen (pot), live together, and run the household
        expenditure from the same income is known as a 'household'. Household
        members should be identified on the basis that they shared a place of
        living together most of time for the past one year. When it is
        difficult to demarcate 'most of the time', living together for the
        past six months or more should be used to find out whether or not
        the person is a household member. For polygamous households, the
        household head should think about all the households and respond
        with respect to all households.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_healtheconomicsupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_healtheconomicsupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: A: Household and head of household**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: meta_subject_healtheconomicsupdate
- column: hh_minors_count
- type: IntegerField
---

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *By head of the household we mean the main decision maker in the household. The head can be either male or female. If two people are equal decision-makers, take the older person.*
- db_table: meta_subject_healtheconomicsupdate
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If No, what is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**6.1.** If OTHER relationship, specify ...
- db_table: meta_subject_healtheconomicsupdate
- column: relationship_to_hoh_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: B: Rooms and beds in your household**

**7.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: meta_subject_healtheconomicsupdate
- column: rooms
- type: IntegerField
---

**8.0.** How many rooms are used for sleeping in your dwelling?
- db_table: meta_subject_healtheconomicsupdate
- column: bedrooms
- type: IntegerField
---

**9.0.** How many beds does your dwelling have in total?
- db_table: meta_subject_healtheconomicsupdate
- column: beds
- type: IntegerField
---

**Section: C: Household income**

**10.0.** Thinking over the last 12 months, can you tell me what the average earnings of the household have been?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**11.0.** Over which <u>time period</u> are you able to estimate?
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**12.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: meta_subject_healtheconomicsupdate
- column: avg_income_value
- type: IntegerField
---

**13.0.** Outside of this household, how many other people depend on this household's income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: meta_subject_healtheconomicsupdate
- column: external_dependents
- type: IntegerField
---

**14.0.** Would you say your household's financial situation is?
- db_table: meta_subject_healtheconomicsupdate
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_healtheconomicsupdate
- column: crf_status_comments
- type: TextField
---


#### Requisitions

* chemistry_rft

* chemistry_lft

* chemistry_lipids

* fbc

### 3000

#### Diabetes Endpoint
A user model to enrolled patient onto the DM Referral
    Schedule.

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_dmendpoint
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_dmendpoint
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Endpoint reached**

**3.0.** Was the patient referred because the diabetes endpoint was reached?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, the EDC will check for the patient on the Endpoints report.*
- db_table: meta_subject_dmendpoint
- column: endpoint_reached
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** Any other comments
- db_table: meta_subject_dmendpoint
- column: comments
- type: TextField
---

**Section: CRF Status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_dmendpoint
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_dmendpoint
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 3060

#### Diabetes Follow-Up After Referral
*[missing model class docstring]*

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_dmfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: meta_subject_dmfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Referral to Diabetes clinic**

**3.0.** Date of referral to diabetes clinic
- db_table: meta_subject_dmfollowup
- column: referral_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: Diabetes clinic attendance**

**4.0.** Did you attend the diabetes clinic following referral from the META Trial
- db_table: meta_subject_dmfollowup
- column: attended
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** If 'Yes', please give the name of the facility you attended
- db_table: meta_subject_dmfollowup
- column: facility_attended
- type: CharField
- length: 50
- responses: *free text*
---

**6.0.** If 'No', please provide a reason for not seeking further care or follow up?
- db_table: meta_subject_dmfollowup
- column: missed_referral_reasons
- type: ManyToManyField
- responses: *Select all that apply*
  - `distance`: *Distance to the clinic*
  - `travel_costs`: *Cost of travel to the clinic*
  - `unable_to_pay_meds`: *Cannot pay for the medication*
  - `dont_want_more_meds`: *I do not want to take more medication*
  - `want_diet_lifestyle_only`: *I planned on doing diet and lifestyle changes only*
  - `traditional_healer`: *Visited a traditional healer*
  - `not_sick`: *I thought I was well and had no diabetes*
  - `dont_like_clinic`: *Do not like the service at the clinic*
  - `OTHER`: *Other, please specify*
---

**7.0.** If other 'reason for not seeking further care', please specify ...
- db_table: meta_subject_dmfollowup
- column: other_missed_referral_reason
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**8.0.** What was the date you attended the health facility named above?
- db_table: meta_subject_dmfollowup
- column: attended_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** What type of health care worker did you see?
- db_table: meta_subject_dmfollowup
- column: healthcare_workers
- type: ManyToManyField
- responses: *Select all that apply*
  - `nurse`: *Nurse*
  - `Doctor`: *Doctor*
  - `community_hcw`: *Community healthcare worker*
  - `OTHER`: *Other, please specify*
---

**10.0.** If other 'healthcare worker', please specify ...
- db_table: meta_subject_dmfollowup
- column: other_healthcare_workers
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Investigations**

**11.0.** Were any further investigations conducted at this visit?
- db_table: meta_subject_dmfollowup
- column: investigations_performed
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If 'Yes', please indicate what investigations were conducted.
- db_table: meta_subject_dmfollowup
- column: investigations
- type: ManyToManyField
- responses: *Select all that apply*
  - `blood_glucose`: *Blood sugar test*
  - `other_tests`: *Other blood tests*
  - `physical_exam`: *Physical examination*
  - `OTHER`: *Other, please specify*
---

**13.0.** If other 'investigations', please specify ...
- db_table: meta_subject_dmfollowup
- column: other_investigations
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** If 'Yes, which diabetes related complications were checked for?
- db_table: meta_subject_dmfollowup
- column: complications_checks
- type: ManyToManyField
- responses: *Select all that apply*
  - `foot`: *Foot check*
  - `eye_disease`: *Diabetic eye disease*
  - `kidney_disease`: *Kidney disease*
  - `heart_disease`: *Heart disease*
---

**Section: Diabetes treatment**

**15.0.** Was any treatment prescribed at this visit?
- db_table: meta_subject_dmfollowup
- column: treatment_prescribed
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**16.0.** What treatment was prescribed?
- db_table: meta_subject_dmfollowup
- column: dm_treatments
- type: ManyToManyField
- responses: *Select all that apply*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `drugs`: *Oral drugs*
  - `insulin`: *Insulin injections*
---

**17.0.** Are you currently taking any drug therapy for diabetes?
- db_table: meta_subject_dmfollowup
- column: on_dm_medications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**18.0.** If 'Yes', please give the date when drug treatment was started.
- db_table: meta_subject_dmfollowup
- column: dm_medications_init_date
- type: DateField
- format: YYYY-MM-DD
---

**19.0.** If 'Yes', please indicate which diabetes drug treatments you are currently taking.
- db_table: meta_subject_dmfollowup
- column: dm_medications
- type: ManyToManyField
- responses: *Select all that apply*
  - `metformin`: *Metformin*
  - `glibenclamide`: *Glibenclamide*
  - `gliclazide`: *Gliclazide*
  - `pioglitazone`: *Pioglitazone*
  - `sitagliptin`: *Sitagliptin*
  - `Vildagliptin`: *vildagliptin*
  - `dapagliflozin`: *Dapagliflozin*
  - `epagliflozin`: *Epagliflozin*
  - `insulin`: *Insulin*
  - `OTHER`: *Other, please specify*
---

**20.0.** If other 'drug treatments', please specify ...
- db_table: meta_subject_dmfollowup
- column: other_dm_medications
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Diabetes Medication Adherence**

**21.0.** Are you taking the diabetes drug treatments regularly, i.e. every day?
- db_table: meta_subject_dmfollowup
- column: medications_adherent
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**22.0.** When was the last time you missed your study pill?
- db_table: meta_subject_dmfollowup
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**Section: Visual Score**

**23.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_dmfollowup
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**24.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: meta_subject_dmfollowup
- column: visual_score_confirmed
- type: IntegerField
---

**Section: CRF Status**

**25.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_dmfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**26.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_dmfollowup
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**27.0.** action identifier
- db_table: meta_subject_dmfollowup
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**28.0.** action item
- db_table: meta_subject_dmfollowup
- column: action_item
- type: ForeignKey
---

**29.0.** parent action item
- db_table: meta_subject_dmfollowup
- column: parent_action_item
- type: ForeignKey
---

**30.0.** related action item
- db_table: meta_subject_dmfollowup
- column: related_action_item
- type: ForeignKey
---


#### Requisitions

### 2000

#### Delivery
A user model to capture delivery and birth outcomes.

    See also in signals `update_pregnancy_notification_on_delivery_post_save`

*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: meta_subject_delivery
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date and Time
- db_table: meta_subject_delivery
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Source of information**

**3.0.** Were you able to obtain a report on the delivery?

&nbsp;&nbsp;&nbsp;&nbsp; *If NO, please explain below*
- db_table: meta_subject_delivery
- column: info_available
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If the report was not available, please explain?
- db_table: meta_subject_delivery
- column: info_not_available_reason
- type: TextField
---

**5.0.** Who / what is the MAIN source of this information?
- db_table: meta_subject_delivery
- column: info_source
- type: CharField
- length: 25
- responses:
  - `patient`: *Study participant*
  - `OTHER`: *Other*
  - `N/A`: *Not applicable*
---

**5.1.** If not reported from study participant, please give the name and contact details of the informant.

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: meta_subject_delivery
- column: info_source_other
- type: CharField
- length: 71
- responses: *free text*
---

**6.0.** Informants relationship to the participant?
- db_table: meta_subject_delivery
- column: informant_relation
- type: CharField
- length: 25
- responses:
  - `husband_wife`: *Husband/wife*
  - `Parent`: *Parent*
  - `child`: *Child*
  - `unknown`: *Unknown*
  - `OTHER`: *Other*
  - `hospital_clinic`: *Hospital / Clinic records*
  - `N/A`: *Not applicable*
---

**6.1.** If other, please specify ...
- db_table: meta_subject_delivery
- column: informant_relation_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Delivery**

**7.0.** Date and time of delivery :

&nbsp;&nbsp;&nbsp;&nbsp; *If TIME unknown, estimate*
- db_table: meta_subject_delivery
- column: delivery_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**8.0.** Is the delivery TIME estimated?
- db_table: meta_subject_delivery
- column: delivery_time_estimated
- type: CharField
- length: 3
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**9.0.** Where did the delivery occur?
- db_table: meta_subject_delivery
- column: delivery_location
- type: CharField
- length: 25
- responses:
  - `home`: *At home*
  - `hospital_clinic`: *Hospital / Clinic*
  - `OTHER`: *Other location, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If other, please specify ...
- db_table: meta_subject_delivery
- column: delivery_location_other
- metadata: None
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** If delivery occurred at a `hospital` or `clinic`, please give name of the facility
- db_table: meta_subject_delivery
- column: delivery_location_name
- type: CharField
- length: 150
- responses: *free text*
---

**11.0.** Gestational age at delivery
- db_table: meta_subject_delivery
- column: delivery_ga
- type: IntegerField
---

**12.0.** Was the participant treated for gestational diabetes?
- db_table: meta_subject_delivery
- column: gm_treated
- type: CharField
- length: 5
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**13.0.** What was the maternal outcome of the pregnancy?
- db_table: meta_subject_delivery
- column: maternal_outcome
- type: CharField
- length: 50
- responses:
  - `no_complications`: *No complications*
  - `complications_full_recovery`: *Complications with full recovery*
  - `complications_ongoing_recovery`: *Complications with ongoing recovery*
  - `dead`: *Maternal mortality*
  - `N/A`: *Not applicable*
---

**Section: Outcomes**

**14.0.** Number of births / fetal / neonatal outcomes

&nbsp;&nbsp;&nbsp;&nbsp; *Each to be reported individually below*
- db_table: meta_subject_delivery
- column: fetal_outcome_count
- type: IntegerField
---

**Section: CRF Status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: meta_subject_delivery
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: meta_subject_delivery
- column: crf_status_comments
- type: TextField
---

**Section: Action**

**17.0.** action identifier
- db_table: meta_subject_delivery
- column: action_identifier
- type: CharField
- length: 50
- responses: *free text*
---

**18.0.** action item
- db_table: meta_subject_delivery
- column: action_item
- type: ForeignKey
---

**19.0.** parent action item
- db_table: meta_subject_delivery
- column: parent_action_item
- type: ForeignKey
---

**20.0.** related action item
- db_table: meta_subject_delivery
- column: related_action_item
- type: ForeignKey
---


#### Requisitions



*Rendered on 2024-12-05 14:44*
